@@ -37,7 +37,8 @@ from disdat import logger as _logger
 S3_LS_USE_MP_THRESH = 4000  # the threshold after which we should use MP to look up bundles on s3
 
 MP_CONTEXT_TYPE = 'forkserver'  # Use for published version
-# MP_CONTEXT_TYPE = 'fork'        # Use for testing
+#MP_CONTEXT_TYPE = 'fork'       # Use for testing
+MAX_TASKS_PER_CHILD = 100       # Force the pool to kill workers when they've done 100 tasks.
 
 
 def batch_get_job_definition_name(pipeline_image_name):
@@ -373,24 +374,29 @@ def ls_s3_url_keys(s3_url, is_object_directory=False):
 
     hexes = '0123456789abcdef'
 
-    MAX_WAIT = 12 * 60
     multiple_results = []
 
     # MacOS X fails when we multi-process using fork and boto sessions.
     # One fix is to set export OBJC_DISABLE_INITIALIZE_FORK_SAFETY=YES
     mp_ctxt = get_context(MP_CONTEXT_TYPE)
-    pool = mp_ctxt.Pool(processes=mp_ctxt.cpu_count()) # I/O bound, so let it use at least cpu_count()
+
+    est_cpu_count = mp_ctxt.cpu_count()
+    print("ls_s3_url_keys using MP with cpu_count {}".format(est_cpu_count))
+    pool = mp_ctxt.Pool(processes=est_cpu_count, maxtasksperchild=MAX_TASKS_PER_CHILD)
 
     prefixes = ['']
     if is_object_directory:
         prefixes = [f'{c}{d}' for c in hexes for d in hexes]
 
+    results = []
+
     if is_object_directory:
         for i, prefix in enumerate(prefixes):
             prefix = os.path.join(s3_path, prefix)
-            multiple_results.append(pool.apply_async(s3_list_objects_at_prefix_v2, (bucket, prefix)))
+            multiple_results.append(pool.apply_async(s3_list_objects_at_prefix_v2,
+                                                     (bucket, prefix),
+                                                     callback=results.extend))
         pool.close()
-        results = [item for res in multiple_results for item in res.get(timeout=MAX_WAIT)]
         pool.join()
     else:
         results = s3_list_objects_at_prefix_v2(bucket, s3_path)
@@ -435,8 +441,6 @@ def ls_s3_url(s3_url):
     result = []
     client = b3.client('s3')
     paginator = client.get_paginator('list_objects_v2')
-    # use delimiter to groupby, which means, list things only at this level.
-    #page_iterator = paginator.paginate(Bucket=bucket, Delimiter='/', Prefix=s3_path)
     page_iterator = paginator.paginate(Bucket=bucket,Prefix=s3_path)
     for page in page_iterator:
         result += page['Contents']
@@ -465,15 +469,14 @@ def delete_s3_dir_many(s3_urls):
         number objects deleted (int)
 
     """
-    MAX_WAIT = 12 * 60
     mp_ctxt = get_context(MP_CONTEXT_TYPE)  # Using forkserver here causes moto / pytest failures
-    pool = mp_ctxt.Pool(processes=mp_ctxt.cpu_count())
+    pool = mp_ctxt.Pool(processes=mp_ctxt.cpu_count(), maxtasksperchild=MAX_TASKS_PER_CHILD)
     multiple_results = []
+    results = []
     for s3_url in s3_urls:
-        multiple_results.append(pool.apply_async(delete_s3_dir, (s3_url,)))
+        multiple_results.append(pool.apply_async(delete_s3_dir, (s3_url,), callback=results.extend))
 
     pool.close()
-    results = [res.get(timeout=MAX_WAIT) for res in multiple_results]
     pool.join()
     return sum([1 if r > 0 else 0 for r in results])
 
@@ -527,6 +530,23 @@ def cp_s3_file(s3_src_path, s3_root):
     return os.path.join("s3://", bucket, output_path)
 
 
+def cp_local_to_s3_file(local_file, s3_file):
+    """
+    Put fqp local file to fqp s3_file
+
+    Args:
+        local_file (str): Fully qualified path to local file
+        s3_file (str): Fully qualified path to file on s3
+
+    Returns:
+        s3_file
+    """
+    s3 = b3.resource('s3')
+    bucket, s3_path = split_s3_url(s3_file)
+    s3.Object(bucket, s3_path).upload_file(local_file, ExtraArgs={"ServerSideEncryption": "AES256"})
+    return s3_file
+
+
 def put_s3_file(local_path, s3_root):
     """
     Put local file to location at s3_root.
@@ -540,6 +560,8 @@ def put_s3_file(local_path, s3_root):
     """
     s3 = b3.resource('s3')
     bucket, s3_path = split_s3_url(s3_root)
+    if s3_path is None:
+        s3_path = ''
     filename = os.path.basename(local_path)
     s3.Object(bucket, os.path.join(s3_path, filename)).upload_file(local_path, ExtraArgs={"ServerSideEncryption": "AES256"})
     return filename
@@ -563,7 +585,6 @@ def get_s3_key(bucket, key, filename=None):
     """
     dl_retry = 3
     s3 = b3.resource('s3')
-    #print(f"get_s3_key the b3[{b3}] and client[{b3.client} and resource[{b3.resource}]")
 
     if filename is None:
         filename = os.path.basename(key)
@@ -606,16 +627,18 @@ def get_s3_key_many(bucket_key_file_tuples):
         filenames (list): list of filenames
 
     """
-    MAX_WAIT = 12 * 60
     mp_ctxt = get_context(MP_CONTEXT_TYPE)  # Using forkserver here causes moto / pytest failures
-    pool = mp_ctxt.Pool(processes=mp_ctxt.cpu_count())
+    est_cpu_count = mp_ctxt.cpu_count()
+    print("get_s3_key_many using MP with cpu_count {}".format(est_cpu_count))
+    pool = mp_ctxt.Pool(processes=est_cpu_count, maxtasksperchild=MAX_TASKS_PER_CHILD)
     multiple_results = []
+    results = []
     for s3_bucket, s3_key, local_object_path in bucket_key_file_tuples:
         multiple_results.append(pool.apply_async(get_s3_key,
-                                                 (s3_bucket, s3_key, local_object_path)))
+                                                 (s3_bucket, s3_key, local_object_path),
+                                                 callback=results.extend))
 
     pool.close()
-    results = [res.get(timeout=MAX_WAIT) for res in multiple_results]
     pool.join()
     return results
 
